#[repr(i32)]pub enum MessageType {
Show 13 variants
None = 0,
CastAdd = 1,
CastRemove = 2,
ReactionAdd = 3,
ReactionRemove = 4,
LinkAdd = 5,
LinkRemove = 6,
VerificationAddEthAddress = 7,
VerificationRemove = 8,
UserDataAdd = 11,
UsernameProof = 12,
FrameAction = 13,
LinkCompactState = 14,
}Expand description
- Type of the MessageBody
Variants
None = 0
CastAdd = 1
Add a new Cast
CastRemove = 2
Remove an existing Cast
ReactionAdd = 3
Add a Reaction to a Cast
ReactionRemove = 4
Remove a Reaction from a Cast
LinkAdd = 5
Add a new Link
LinkRemove = 6
Remove an existing Link
VerificationAddEthAddress = 7
Add a Verification of an Ethereum Address
VerificationRemove = 8
Remove a Verification
UserDataAdd = 11
Deprecated MESSAGE_TYPE_SIGNER_ADD = 9; // Add a new Ed25519 key pair that signs messages for a user MESSAGE_TYPE_SIGNER_REMOVE = 10; // Remove an Ed25519 key pair that signs messages for a user
Add metadata about a user
UsernameProof = 12
Add or replace a username proof
FrameAction = 13
A Farcaster Frame action
LinkCompactState = 14
Link Compaction State Message
Implementations
Sourceimpl MessageType
impl MessageType
Sourceimpl MessageType
impl MessageType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.