#[repr(i32)]pub enum UserDataType {
None = 0,
Pfp = 1,
Display = 2,
Bio = 3,
Url = 5,
Username = 6,
Location = 7,
Twitter = 8,
Github = 9,
}Expand description
- Type of UserData
Variants
None = 0
Pfp = 1
Profile Picture for the user
Display = 2
Display Name for the user
Bio = 3
Bio for the user
Url = 5
URL of the user
Username = 6
Preferred Name for the user
Location = 7
Current location for the user
Twitter = 8
Username of user on x
Github = 9
Username of user on github
Implementations
Sourceimpl UserDataType
impl UserDataType
Sourceimpl UserDataType
impl UserDataType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.