pub struct MessageData {
pub type: i32,
pub fid: u64,
pub timestamp: u32,
pub network: i32,
pub body: Option<Body>,
}Expand description
A MessageData object contains properties common to all messages and wraps a body object which contains properties specific to the MessageType.
Fields
type: i32Type of message contained in the body
fid: u64Farcaster ID of the user producing the message
timestamp: u32Farcaster epoch timestamp in seconds
network: i32Farcaster network the message is intended for
body: Option<Body>Implementations
Sourceimpl MessageData
impl MessageData
Sourcepub fn type(&self) -> MessageType
pub fn type(&self) -> MessageType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: MessageType)
pub fn set_type(&mut self, value: MessageType)
Sets type to the provided enum value.
Sourcepub fn network(&self) -> FarcasterNetwork
pub fn network(&self) -> FarcasterNetwork
Returns the enum value of network, or the default if the field is set to an invalid enum value.
Sourcepub fn set_network(&mut self, value: FarcasterNetwork)
pub fn set_network(&mut self, value: FarcasterNetwork)
Sets network to the provided enum value.