pub struct VerificationAddAddressBody {
pub address: Vec<u8>,
pub claim_signature: Vec<u8>,
pub block_hash: Vec<u8>,
pub verification_type: u32,
pub chain_id: u32,
pub protocol: i32,
}Expand description
- Adds a Verification of ownership of an Address based on Protocol
Fields
address: Vec<u8>Address being verified for a given Protocol
claim_signature: Vec<u8>Signature produced by the user’s address for a given Protocol
block_hash: Vec<u8>Hash of the latest Ethereum block when the signature was produced
verification_type: u32Type of verification. 0 = EOA, 1 = contract
chain_id: u320 for EOA verifications, 1 or 10 for contract verifications
protocol: i32Protocol of the Verification
Implementations